@@ -14,6 +14,8 @@
 import os
 import sys
 import math
+from typing import Union, List
+
 import numpy as np
 import tensorflow as tf
 
@@ -45,7 +47,7 @@ def check_key_in_dict(dictionary, keys):
             raise ValueError("{} must be defined".format(key))
 
 
-def preprocess_paths(paths):
+def preprocess_paths(paths: Union[List, str]):
     if isinstance(paths, list):
         return [os.path.abspath(os.path.expanduser(path)) for path in paths]
     return os.path.abspath(os.path.expanduser(paths)) if paths else None
@@ -82,6 +84,15 @@ def get_rnn(rnn_type):
     return tf.keras.layers.SimpleRNN
 
 
+def get_conv(conv_type):
+    assert conv_type in ["conv1d", "conv2d"]
+
+    if conv_type == "conv1d":
+        return tf.keras.layers.Conv1D
+
+    return tf.keras.layers.Conv2D
+
+
 def print_one_line(*args):
     tf.print("\033[K", end="")
     tf.print("\r", *args, sep="", end=" ", output_stream=sys.stdout)
